Crate recall_fendermint_vm_genesis

Crate recall_fendermint_vm_genesis 

A Genesis data structure similar to genesis.Template in Lotus, which is used to initialize the state tree.

Modules

ipc
IPC related data structures.

Structs

Account
Actor
Collateral
Total amount of tokens delegated to a validator.
Genesis
The genesis data structure we serialize to JSON and start the chain with.
Multisig
Power
Total voting power of a validator.
SignerAddr
Wrapper around Address to provide human readable serialization in JSON format.
Validator
A genesis validator with their initial power.
ValidatorKey
Secp256k1 public key of the validators.

Enums

ActorMeta
PermissionMode

Type Aliases

PowerScale
Power conversion decimal points, e.g. 3 decimals means 1 power per milliFIL.